Crate iceoryx2_bb_testing

Crate iceoryx2_bb_testing 

Testing utilities and helpers.

These utilities may leverage components in the building blocks layer of the architecture.

Components from iceoryx2_pal_testing are re-exported for convenience of use in upper layers.

Re-exports

pub use inventory;

Modules

abandon_tracker
assert
instantiate_conformance_tests_macro
internal
lifetime_tracker
memory
test_harness
watchdog

Macros

assert_that
instantiate_conformance_tests
This macro is used to instantiate conformance tests for a given set of system-under-test (SUT) types.
instantiate_conformance_tests_with_module
This is a convenience macro for instantiate_conformance_tests, to instantiate conformance tests for a given set of system-under-test (SUT) types and automatically wrap them in a module.
test_fail
test_harness
test_requires

Structs

TestCase

Enums

RequiresStd
RunMode

Constants

AT_LEAST_TIMING_VARIANCE