RawMemory

Struct RawMemory 

pub struct RawMemory<T> { /* private fields */ }
Allocates uninitialized memory on the heap. When it goes out of scope the memory is released. The user has to ensure that the memory is initialized.

Implementations

Source

impl<T> RawMemory<T>

pub fn new<F>(fill: F) -> RawMemory<T>
where F: FnMut(usize) -> u8,

Allocates memory to fit in a T and fills the memory with values provided by the fill callback.

pub fn new_zeroed() -> RawMemory<T>

Allocates zeroed memory to fit in a T.

pub fn new_filled(value: u8) -> RawMemory<T>

Allocates memory filled with a given value to fit in a T.

pub fn as_ptr(&self) -> *const T

Returns a const pointer to T

pub fn as_mut_ptr(&self) -> *mut T

Returns a mutable pointer to T

pub unsafe fn assume_init(&self) -> &T

Returns a const reference to T

Safety
  • T must have been constructed manually before calling this function.
pub unsafe fn assume_init_mut(&mut self) -> &mut T

Returns a mutable reference to T

Safety
  • T must have been constructed manually before calling this function.
pub fn as_slice(&self) -> &[u8]

Returns a slice to the underlying memory

pub fn as_slice_mut(&mut self) -> &mut [u8]

Returns a mutable slice to the underlying memory