Testing utilities and helpers.
These utilities may leverage components in the building blocks layer of the architecture.
Components from iceoryx2_pal_testing are re-exported for convenience
of use in upper layers.
Re-exports
pub use inventory;
Modules
- abandon_
tracker - assert
- instantiate_
conformance_ tests_ macro - internal
- lifetime_
tracker - memory
- test_
harness - watchdog
Macros
- assert_
that - instantiate_
conformance_ tests - This macro is used to instantiate conformance tests for a given set of system-under-test (SUT) types.
- instantiate_
conformance_ tests_ with_ module - This is a convenience macro for
instantiate_conformance_tests, to instantiate conformance tests for a given set of system-under-test (SUT) types and automatically wrap them in a module. - test_
fail - test_
harness - test_
requires